import{d as u,eB as f,G as b,b as y,c as g,u as _}from"./outputWidgets.a5fcf389.js";import{a as w}from"./asyncComputed.b7d3265e.js";import"./router.8a74f04b.js";import"./index.b67da7e9.js";import{M as n}from"./member.bfbe771d.js";import{C as I}from"./CrudView.cee1047f.js";import"./Base.175f3ec4.js";import"./transButton.fc314012.js";import"./Text.d2260f67.js";import"./Title.42ad4bfb.js";import"./index.39083dd8.js";import"./record.e2e84f62.js";import"./pubsub.903f7e54.js";import"./gateway.5878b159.js";import"./icons.1a1dc210.js";import"./url.d6641ded.js";import"./index.48f4731a.js";import"./index.5b7d1aca.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="786c09af-b6f7-4f6a-88a4-8a84ae1d9239",e._sentryDebugIdIdentifier="sentry-dbid-786c09af-b6f7-4f6a-88a4-8a84ae1d9239")}catch{}})();const q=u({__name:"Members",setup(e){const o=f().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(o,t.email),p()},{loading:l,result:d,refetch:p}=w(()=>n.list(o)),c=b(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{q as default};
//# sourceMappingURL=Members.b271ce35.js.map
