import{U as i}from"./outputWidgets.a5fcf389.js";import{c as a,d}from"./index.440639bd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="96b71c0b-940d-41bf-9869-0c4e91e7065d",e._sentryDebugIdIdentifier="sentry-dbid-96b71c0b-940d-41bf-9869-0c4e91e7065d")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:o,RangePicker:c}=a(d),y=i(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:c,TimePicker:m,QuarterPicker:o,install:e=>(e.component(n.name,n),e.component(c.name,c),e.component(t.name,t),e.component(r.name,r),e.component(o.name,o),e)});export{y as D,t as M,o as Q,c as R,r as W};
//# sourceMappingURL=dayjs.4c9a6853.js.map
