import{t,b as s,eu as o}from"./outputWidgets.a5fcf389.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="0cb6678b-4c81-4e73-8961-8762f3758368",e._sentryDebugIdIdentifier="sentry-dbid-0cb6678b-4c81-4e73-8961-8762f3758368")}catch{}})();const r={},i={class:"organization-settings"};function c(e,n){return s(),o("div",i,"Organization settings")}const f=t(r,[["render",c]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.1c94d8c9.js.map
