import"./outputWidgets.a5fcf389.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="f850ae56-d2a6-4db1-a329-fce277ceaf8b",e._sentryDebugIdIdentifier="sentry-dbid-f850ae56-d2a6-4db1-a329-fce277ceaf8b")}catch{}})();function f(e,a){const i=document,d=e.matched.slice().reverse().find(t=>t.meta&&t.meta.title),n=a.matched.slice().reverse().find(t=>t.meta&&t.meta.metaTags);d?i.title=d.meta.title:n&&(i.title=n.meta.title)}export{f as u};
//# sourceMappingURL=index.39083dd8.js.map
