import{t as o,a as i,b as a,c,i as d,T as p,j as u,P as f,C as _,M as l,s as g,k as s,l as m,m as y,n as v,p as b}from"./outputWidgets.a5fcf389.js";import{u as w,s as h,a as r}from"./index.a574b8a7.js";import"./pubsub.903f7e54.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6e552d18-ff3f-4c59-8a45-eae1c3017eec",e._sentryDebugIdIdentifier="sentry-dbid-6e552d18-ff3f-4c59-8a45-eae1c3017eec")}catch{}})();const I={};function k(e,t){const n=i("router-view");return a(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",k]]);class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await Promise.all([w(),h()]);const e=d({render:()=>m(x)});p.init(),u(e,r),P.init(),e.use(r),e.use(f),e.mount("#app"),e.component("VSelect",_),e.component("Markdown",l),e.component("Message",g),s(e,y),s(e,v),s(e,b)})();
//# sourceMappingURL=player.74f12368.js.map
