import"./outputWidgets.a5fcf389.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9f726eb2-ebb2-45ae-8421-e0a48fbd449f",e._sentryDebugIdIdentifier="sentry-dbid-9f726eb2-ebb2-45ae-8421-e0a48fbd449f")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.d6641ded.js.map
