import{cz as r}from"./outputWidgets.a5fcf389.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="9f50411f-8ddb-4260-8bbd-bbe996d6feea",e._sentryDebugIdIdentifier="sentry-dbid-9f50411f-8ddb-4260-8bbd-bbe996d6feea")}catch{}})();const o=(e,d)=>{r.error({message:e,description:d})};export{o as p};
//# sourceMappingURL=popupNotifcation.f267868b.js.map
